# autoflake: skip_file

from typing import TypeAlias, Union

from codetocad.core.angle import Angle
from codetocad.core.dimension import Dimension
from codetocad.core.dimensions import Dimensions
from codetocad.core.point import Point
from codetocad.core.boundary_box import BoundaryBox
from codetocad.core.boundary_axis import BoundaryAxis
from codetocad.core.part_options import PartOptions
from codetocad.core.sketch_options import SketchOptions
from codetocad.enums.angle_unit import AngleUnit
from codetocad.enums.axis import Axis
from codetocad.enums.constraint_types import ConstraintTypes
from codetocad.enums.curve_primitive_types import CurvePrimitiveTypes
from codetocad.enums.curve_types import CurveTypes
from codetocad.enums.length_unit import LengthUnit
from codetocad.enums.preset_landmark import PresetLandmark
from codetocad.enums.file_formats import FileFormats
from codetocad.enums.preset_material import PresetMaterial
from codetocad.enums.scaling_methods import ScalingMethods
from codetocad.enums.units import Units
from codetocad.enums.boolean_operation import BooleanOperation

# from codetocad.interfaces.booleanable_interface import BooleanableInterface
# from codetocad.interfaces.camera_interface import CameraInterface
# from codetocad.interfaces.entity_interface import EntityInterface
# from codetocad.interfaces.exportable_interface import ExportableInterface
# from codetocad.interfaces.landmark_interface import LandmarkInterface
# from codetocad.interfaces.landmarkable_interface import LandmarkableInterface
# from codetocad.interfaces.material_interface import MaterialInterface
# from codetocad.interfaces.part_interface import PartInterface
# from codetocad.interfaces.sketch_interface import SketchInterface
# from codetocad.interfaces.vertex_interface import VertexInterface
